@@ -29,6 +29,8 @@ class SystemManager:
         user (str): User to login with.
         password (str): Password associated with the user.
         smartphone_id (str): This is required by the API to login.
+        serial (str): If you have multiple facilities,
+            you can specify which one to access
     """
     # pylint: disable=too-many-arguments
     def __init__(self,
@@ -84,7 +86,8 @@ class SystemManager:
         gateway = await gateway_req
         facilities = await facilities_req
         hvac_state = await hvac_state_req
-        system_info = mapper.map_system_info(facilities, gateway, hvac_state)
+        system_info = mapper.map_system_info(
+            facilities, gateway, hvac_state, self._serial)
 
         boiler_status = mapper.map_boiler_status(hvac_state)
         errors = mapper.map_errors(hvac_state)
@@ -590,7 +593,7 @@ class SystemManager:
                                              mode: OperatingMode) -> None:
         """Set ventilation at night level.
          Compatible modes are listed here
-         :class:`~pymultimatic.model.Ventilation.MODES
+         :class:`~pymultimatic.model.Ventilation.MODES`
 
         Args:
             ventilation_id (str): id of the ventilation
